@@ -2,7 +2,7 @@ library(ggplot2)
 library(ggrepel)
 
 # Read in the input file as a matrix 
-data <- as.matrix(read.table("matrix.txt", header = TRUE, row.names = 1))
+data <- as.matrix(read.table("matrix.txt", header = TRUE, row.names = 1, check.names = FALSE))
 
 # Calculate distance matrix
 #d <- dist(data)
